# ogGui - OpenGnsys Administration Interface

## Introduction

Welcome to the new OpenGnsys administration interface. This manual will guide you through your first steps in setting up and efficiently using the platform. The new web console represents a qualitative leap with the following main features

!!! info
    - Developed with Angular 18, a modern and up-to-date framework
    - Responsive web design that works both on PC environments and mobile devices
    - Multilingual support with English translation

## System Access

To start using OpenGnsys

1. Open your preferred web browser
2. Enter the URL of the OpenGnsys server
3. On the login screen, enter your credentials (username and password)

Click on "Log In"

![oggui-login.png](../assets/images/screenshots/oggui-login.png)

## Main Interface

Once inside, you will find:

- **Side navigation panel**: Access to all modules and functionalities
- **Top bar**: User information, notifications, and quick access to settings
- **Central workspace**: Where the selected information is displayed and managed

![Consola Web OpenGnsys](../assets/images/screenshots/ogintro-webconsole.png)

## Initial Configuration

### User Management

User management allows you to control who has access to the system and what they can do.

![Menú de configuración](../assets/images/screenshots/oggui-config_menu.png)

#### Viewing Existing Users

Go to **Administration > Users** to view the list of current system users.

![Lista de usuarios](../assets/images/screenshots/oggui-config_usuarios.png)

#### Adding a New User

1. On the Users page, click the "Add Users" button
2. Complete the form with the following data:

![Añadir usuario](../assets/images/screenshots/oggui-administracion-usuarios-anadir_usuario.png)

- **Username**: Unique identifier for logging in
- **Password**: Access key (note: only administrators can change passwords)
- **Role**: Select one or more roles that will define the user's permissions
- **Organizational Unit**: Defines which groups of classrooms or machines the user will be able to administer

3. Click "Save" to create the new user

#### Editing an Existing User

1. In the user list, locate the user you want to edit
2. Click the edit icon (pencil)
3. Update the necessary fields
4. Save the changes

#### Deleting a User

1. In the user list, locate the user you want to delete
2. Click the delete icon (trash can)
3. Confirm the action when prompted

### Role Configuration

Roles define the permissions of users on the platform. OpenGnsys includes four predefined levels:

- **Super Admin**: Full control of the platform, without restrictions
- **Organizational Unit Admin**: Full control over the assigned organizational unit
- **Organizational Unit Operator**: Limited permissions to operate machines in the assigned unit
- **User**: Basic access to the platform

### Environment Variables

Environment variables define the connection configuration with the different components:

1. Go to **Administration > Environment Variables**
2. Configure the following variables according to your infrastructure:

- **OG_CORE_IP**: IP address of the main server
- **OG_DHCP_API_URL**: URL of the DHCP service API
- **OG_BOOT_API_URL**: URL of the boot server API
- **OG_LOG_IP**: IP address of the log server
- **REMOTEPC_AUTH_LOGIN**: Authentication URL for RemotePC
- **REMOTEPC_AUTH_USERNAME**: Username for RemotePC
- **REMOTEPC_AUTH_PASSWORD**: Password for RemotePC
- **REMOTEPC_URL**: Base URL of the RemotePC service
- **SSL_ENABLED**: true or false.

![oggui-administracion-env.png](../assets/images/screenshots/oggui-administracion-env.png)

!!! note "Note"
    The UDS_ variables will appear as REMOTEPC_ in your installation

## Navigating the Menus

The left side panel contains all available menus according to your role and the active modules:

- **Groups**: Management of groups
- **Actions**: The management module for Actions, Commands, and Tasks.
- **Subnets**: The management module for the DHCP service.
- **Boot**: The management module for the ogLive and PXE boot services.
- **Calendars**: Module for managing machine availability in the RemotePC service
- **Repositories**: Module for managing repositories and the images associated with each.
- **Menus**: Allows managing the menus that will be displayed when starting ogLive on a client machine.

!!! note "Note"
    Some modules may not be available if they depend on external services that are not configured. For example, if the DHCP service is managed externally, accessing that menu will display a notice indicating that the module is not enabled.

--8<-- "sections/oggui-grupos.md"
--8<-- "sections/oggui-acciones.md"
--8<-- "sections/oggui-cierre.md"
